@@ -55,17 +55,21 @@ class APRSDPluginBase(metaclass=abc.ABCMeta):
 
     # Holds the list of APRSDThreads that the plugin creates
     threads = []
+    # Set this in setup()
+    enabled = False
 
     def __init__(self, config):
         self.config = config
         self.message_counter = 0
         self.setup()
-        self.threads = self.create_threads()
+        threads = self.create_threads()
+        if threads:
+            self.threads = threads
         if self.threads:
             self.start_threads()
 
     def start_threads(self):
-        if self.threads:
+        if self.enabled and self.threads:
             if not isinstance(self.threads, list):
                 self.threads = [self.threads]
 
@@ -97,8 +101,10 @@ class APRSDPluginBase(metaclass=abc.ABCMeta):
         """Version"""
         raise NotImplementedError
 
+    @abc.abstractmethod
     def setup(self):
         """Do any plugin setup here."""
+        self.enabled = True
 
     def create_threads(self):
         """Gives the plugin writer the ability start a background thread."""
@@ -137,7 +143,6 @@ class APRSDWatchListPluginBase(APRSDPluginBase, metaclass=abc.ABCMeta):
     by a particular HAM callsign, write a plugin based off of
     this class.
     """
-    enabled = False
 
     def setup(self):
         # if we have a watch list enabled, we need to add filtering
@@ -160,15 +165,18 @@ class APRSDWatchListPluginBase(APRSDPluginBase, metaclass=abc.ABCMeta):
                 LOG.warning("Watch list enabled, but no callsigns set.")
 
     def filter(self, packet):
-        wl = packets.WatchList()
-        result = messaging.NULL_MESSAGE
-        if wl.callsign_in_watchlist(packet["from"]):
-            # packet is from a callsign in the watch list
-            self.rx_inc()
-            result = self.process()
-            if result:
-                self.tx_inc()
-            wl.update_seen(packet)
+        if self.enabled:
+            wl = packets.WatchList()
+            result = messaging.NULL_MESSAGE
+            if wl.callsign_in_watchlist(packet["from"]):
+                # packet is from a callsign in the watch list
+                self.rx_inc()
+                result = self.process()
+                if result:
+                    self.tx_inc()
+                wl.update_seen(packet)
+        else:
+            LOG.warning(f"{self.__class__} plugin is not enabled")
 
         return result
 
@@ -191,6 +199,10 @@ class APRSDRegexCommandPluginBase(APRSDPluginBase, metaclass=abc.ABCMeta):
         """The regex to match from the caller"""
         raise NotImplementedError
 
+    def setup(self):
+        """Do any plugin setup here."""
+        self.enabled = True
+
     @hookimpl
     def filter(self, packet):
         result = None
@@ -208,9 +220,12 @@ class APRSDRegexCommandPluginBase(APRSDPluginBase, metaclass=abc.ABCMeta):
         ):
             if re.search(self.command_regex, message):
                 self.rx_inc()
-                result = self.process(packet)
-                if result:
-                    self.tx_inc()
+                if self.enabled:
+                    result = self.process(packet)
+                    if result:
+                        self.tx_inc()
+                else:
+                    LOG.warning(f"{self.__class__} isn't enabled.")
 
         return result
 
