@@ -26,22 +26,40 @@ LOG_LEVELS = {
     "DEBUG": logging.DEBUG,
 }
 
+DEFAULT_DATE_FORMAT = "%m/%d/%Y %I:%M:%S %p"
 DEFAULT_LOG_FORMAT = (
-    "[%(asctime)s] [%(threadName)-12s] [%(levelname)-5.5s]"
+    "[%(asctime)s] [%(threadName)-20.20s] [%(levelname)-5.5s]"
     " %(message)s - [%(pathname)s:%(lineno)d]"
 )
 
-DEFAULT_DATE_FORMAT = "%m/%d/%Y %I:%M:%S %p"
+QUEUE_DATE_FORMAT = "[%m/%d/%Y] [%I:%M:%S %p]"
+QUEUE_LOG_FORMAT = (
+    "%(asctime)s [%(threadName)-20.20s] [%(levelname)-5.5s]"
+    " %(message)s - [%(pathname)s:%(lineno)d]"
+)
 
 # an example of what should be in the ~/.aprsd/config.yml
 DEFAULT_CONFIG_DICT = {
     "ham": {"callsign": "NOCALL"},
     "aprs": {
-        "login": "NOCALL",
+        "enabled": True,
+        "login": "CALLSIGN",
         "password": "00000",
         "host": "rotate.aprs2.net",
         "port": 14580,
     },
+    "kiss": {
+        "tcp": {
+            "enabled": False,
+            "host": "direwolf.ip.address",
+            "port": "8001",
+        },
+        "serial": {
+            "enabled": False,
+            "device": "/dev/ttyS0",
+            "baudrate": 9600,
+        },
+    },
     "aprsd": {
         "logfile": "/tmp/aprsd.log",
         "logformat": DEFAULT_LOG_FORMAT,
@@ -172,6 +190,9 @@ def add_config_comments(raw_yaml):
         # lets insert a comment
         raw_yaml = insert_str(
             raw_yaml,
+            "\n    # Set enabled to False if there is no internet connectivity."
+            "\n    # This is useful for a direwolf KISS aprs connection only. "
+            "\n"
             "\n    # Get the passcode for your callsign here: "
             "\n    # https://apps.magicbug.co.uk/passcode",
             end_idx,
@@ -272,7 +293,7 @@ def conf_option_exists(conf, chain):
 
 def check_config_option(config, chain, default_fail=None):
     result = conf_option_exists(config, chain.copy())
-    if not result:
+    if result is None:
         raise Exception(
             "'{}' was not in config file".format(
                 chain,
